"""
vxapi
~~~~~

*vxapi* is an unofficial Python client for Virgin America Elevate accounts.

:copyright: (c) 2014 by Anthony Wu.
:license: MIT License, see LICENSE for more details.
"""

__title__ = 'vxapi'
__version__ = '0.0.4'
__author__ = 'Anthony Wu'
__license__ = 'MIT License'
__copyright__ = 'Copyright 2014 Anthony Wu'

try:
	from .api import VirginAmericaWebSession
except ImportError:
	# during initial pip install setup, this file will be read for the metadata properties
	# at that time, not all dependencies have been installed, and this will fail
	# but that's okay
	pass
